package com.example.blum.nflfromjson;

import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.Spinner;
import android.widget.TextView;
import android.widget.Toast;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;

public class MainActivity extends AppCompatActivity {

    //declare a global JSONarray -- the array of objects we will get from reading the JSON file
    JSONArray myJSON_array;
    Spinner spConference;
    Spinner spDivision;
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);


        spConference= (Spinner) findViewById(R.id.spConference);
        spDivision= (Spinner) findViewById(R.id.spDivision);

        try{
            //http://stackoverflow.com/questions/6420293/reading-android-raw-text-file
            InputStream is = getResources().openRawResource(R.raw.nfl);
            byte[] buffer = new byte[is.available()];
            while (is.read(buffer) != -1);

            String myText = new String(buffer);
            //Toast.makeText(getBaseContext(), "Got here", Toast.LENGTH_LONG).show();
            //http://stackoverflow.com/questions/9605913/how-to-parse-json-in-android
            //extract the main (top-level) JSON object from the file read above
            JSONObject myJSON_object = new JSONObject(myText);

            //the main JSON object is/includes an array called NFL
            //extract that array
            myJSON_array = myJSON_object.getJSONArray("NFL");

            List<String> conferences = new ArrayList<String>();
            List<String> divisions = new ArrayList<String>();


            //create two String arrays of conference & division -- used to populate spinner
            for (int i=0; i < myJSON_array.length(); i++){
                try{
                    //get an individual element of the JSON array
                    JSONObject aJSON_element = myJSON_array.getJSONObject(i);
                    //get the individual properties of the JSON element
                    String aConference = aJSON_element.getString("Conference");
                    String aDivision = aJSON_element.getString("Division");

                    //if don't already have conference add it
                    if(conferences.indexOf(aConference) ==-1){
                        conferences.add(aConference);
                    }

                    //if don't already have division add it
                    if(divisions.indexOf(aDivision) ==-1){
                        divisions.add(aDivision);
                    }
                }
                catch (JSONException e)
                {
                    Toast.makeText(getBaseContext(), "Dude, you have to know what the JSON looks like to parse it",
                            Toast.LENGTH_SHORT).show();
                    e.printStackTrace();
                }
            }

            //populate the division and conference spinners
            ArrayAdapter<String> aaConference = new ArrayAdapter<String>(this,   android.R.layout.simple_spinner_item,
                    conferences);
            aaConference.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
            spConference.setAdapter(aaConference);

            ArrayAdapter<String> aaDivision = new ArrayAdapter<String>(this,   android.R.layout.simple_spinner_item,
                    divisions);
            aaDivision.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
            spDivision.setAdapter(aaDivision);


            //************************************************************************************************
            // conference spinner handler
            spConference.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
                @Override
                public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                    //Toast.makeText(getBaseContext(), "conference change", Toast.LENGTH_SHORT).show();
                    updateTeamSpinner();
                }

                @Override
                public void onNothingSelected(AdapterView<?> adapterView) {
                }
            });

            //************************************************************************************************
            // divsion spinner handler
            spDivision.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
                @Override
                public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                    updateTeamSpinner();
                }

                @Override
                public void onNothingSelected(AdapterView<?> adapterView) {
                }
            });

        } //end try to read file
        catch(Exception e){
            Toast.makeText(getBaseContext(), "Problem with file", Toast.LENGTH_LONG).show();
            e.printStackTrace();
        }
    }//end onCreate

    //**********************************************************************************************
    void updateTeamSpinner(){
        final Spinner spTeam = (Spinner) findViewById(R.id.spTeam);
        spTeam.setAdapter(null);
        List<String> teams = new ArrayList<String>();

        String userConference = spConference.getSelectedItem().toString();
        String userDivision = spDivision.getSelectedItem().toString();

        //Toast.makeText(getBaseContext(), userConference, Toast.LENGTH_SHORT).show();
        //Toast.makeText(getBaseContext(), userDivision, Toast.LENGTH_SHORT).show();
        for (int i=0; i < myJSON_array.length(); i++){
            try{
                //get an individual element of the JSON array
                JSONObject aJSON_element = myJSON_array.getJSONObject(i);
                //get the individual properties of the JSON element
                String aConference = aJSON_element.getString("Conference");
                String aDivision = aJSON_element.getString("Division");

                if(aConference.equals(userConference) && aDivision.equals(userDivision)){
                    String aCity = aJSON_element.getString("City");
                    String aTeam = aJSON_element.getString("TeamName");
                    teams.add(aCity+" "+aTeam);
                }
            }
            catch (JSONException e)
            {
                Toast.makeText(getBaseContext(), "Dude, you have to know what the JSON looks like to parse it",
                        Toast.LENGTH_SHORT).show();
                e.printStackTrace();
            }
        }

        ArrayAdapter<String> aaTeam = new ArrayAdapter<String>(getBaseContext(),   android.R.layout.simple_spinner_item,
                teams);
        aaTeam.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item); // The drop down view
        spTeam.setAdapter(aaTeam);

        spTeam.setOnItemSelectedListener(new AdapterView.OnItemSelectedListener() {
            @Override
            public void onItemSelected(AdapterView<?> adapterView, View view, int i, long l) {
                //Toast.makeText(getBaseContext(), "chose Team", Toast.LENGTH_SHORT).show();
                TextView mytv = (TextView) view;
                String myTeam = mytv.getText().toString();
                //spinner has city and team -- get just team
                String[] tokens = myTeam.split(" ");
                myTeam = tokens[tokens.length -1];

                //Toast.makeText(getBaseContext(), "chose Team: "+myTeam, Toast.LENGTH_SHORT).show();
                TextView tvCoach = (TextView) findViewById(R.id.tvCoach);
                ImageView ivTeam = (ImageView) findViewById(R.id.ivTeam);

                try {
                    for (int j = 0; j < myJSON_array.length(); j++) {
                        if (myJSON_array.getJSONObject(j).getString("TeamName").equals(myTeam)) {
                            tvCoach.setText(myJSON_array.getJSONObject(j).getString("Coach"));
                            // string off file extension -- then file corresponding id
                            String imagefile = myJSON_array.getJSONObject(j).getString("Image");
                            imagefile = imagefile.substring(0, imagefile.lastIndexOf("."));
                            //Toast.makeText(getBaseContext(), imagefile, Toast.LENGTH_SHORT).show();
                            int draw_res_id = getResources().getIdentifier(imagefile, "drawable", getPackageName());
                            ivTeam.setImageResource(draw_res_id);
                        }
                    }
                }catch(JSONException e){
                }
            }

            @Override
            public void onNothingSelected(AdapterView<?> adapterView) {

            }
        });

    }

}//end MainActivity

